Learn R Programming

available (version 0.0.0.9000)

find_acronym: Function that finds and returns the first acronym (all caps) in a text string

Description

Function that finds and returns the first acronym (all caps) in a text string

Usage

find_acronym(title)

Arguments

title

package title or discription

Value

a single acronym, if present