Learn R Programming

available (version 0.0.0.9000)

namr: Suggest package name

Description

Suggest package name

Usage

namr(title, acronym = F, verb = F, ...)

Arguments

title

the package title or discription

acronym

whether to include an acronym (if there is one) in the title

verb

whether to prioritize using a verb in the package title

Value

a single word to use as a package title