suggest: Suggest a title based for a development package
Description
If the package you are using already has a title, simply pass the path to
the package root in `path`. Otherwise use `title` to specify a potential
title.
Usage
suggest(path = ".", title = NULL)
Arguments
path
Path to a existing package to extract the title from.